Module error

Module error 

Enums

ApiError
Matches errors that are returned from the Spotfiy API as part of the JSON response object.
ModelError
Groups up the kinds of errors that may happen in this crate.

Type Aliases

ApiResult
ModelResult