SimplifiedPlaylist

Struct SimplifiedPlaylist 

pub struct SimplifiedPlaylist {
    pub collaborative: bool,
    pub external_urls: HashMap<String, String>,
    pub href: String,
    pub id: PlaylistId<'static>,
    pub images: Vec<Image>,
    pub name: String,
    pub owner: PublicUser,
    pub public: Option<bool>,
    pub snapshot_id: String,
    pub tracks: PlaylistTracksRef,
    pub items: PlaylistTracksRef,
}
Simplified playlist object

Note: The tracks field was renamed to items by Spotify. This struct uses an internal “shadow” struct for deserialization to ensure that both fields are correctly populated regardless of whether Spotify sends the old or new key. This maintains compatibility before, during and after the February 2026 API migration.

Fields

collaborative: boolexternal_urls: HashMap<String, String>href: Stringid: PlaylistId<'static>images: Vec<Image>name: Stringowner: PublicUserpublic: Option<bool>snapshot_id: Stringtracks: PlaylistTracksRef
👎Deprecated since 0.16.0:

Renamed to items by Spotify. Use items instead. See https://github.com/ramsayleung/rspotify/issues/550

Note: This field is kept for compatibility before, during and after Spotify’s February 2026 API migration. It is synced with items during deserialization.

items: PlaylistTracksRef