pub struct FullPlaylist {Show 13 fields
pub collaborative: bool,
pub description: Option<String>,
pub external_urls: HashMap<String, String>,
pub followers: Followers,
pub href: String,
pub id: PlaylistId<'static>,
pub images: Vec<Image>,
pub name: String,
pub owner: PublicUser,
pub public: Option<bool>,
pub snapshot_id: String,
pub tracks: Page<PlaylistItem>,
pub items: Page<PlaylistItem>,
}Expand description
Full playlist object
Note: The tracks field was renamed to items by Spotify. This struct
uses an internal “shadow” struct for deserialization to ensure that both
fields are correctly populated regardless of whether Spotify sends the old
or new key. This maintains compatibility before, during and after the
February 2026 API migration.
Fields
collaborative: booldescription: Option<String>external_urls: HashMap<String, String>followers: Followershref: Stringid: PlaylistId<'static>images: Vec<Image>name: Stringowner: PublicUserpublic: Option<bool>snapshot_id: Stringtracks: Page<PlaylistItem>👎Deprecated since 0.16.0:
Renamed to items by Spotify. Use items instead. See https://github.com/ramsayleung/rspotify/issues/550
Note: This field is kept for compatibility before, during and after
Spotify’s February 2026 API migration. It is synced with items
during deserialization.
items: Page<PlaylistItem>Trait Implementations
Sourceimpl Clone for FullPlaylist
impl Clone for FullPlaylist
Sourcefn clone(&self) -> FullPlaylist
fn clone(&self) -> FullPlaylist
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FullPlaylist
impl Debug for FullPlaylist
Sourceimpl<'de> Deserialize<'de> for FullPlaylist
impl<'de> Deserialize<'de> for FullPlaylist
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FullPlaylist
impl PartialEq for FullPlaylist
Sourceimpl Serialize for FullPlaylist
impl Serialize for FullPlaylist
impl Eq for FullPlaylist
impl StructuralPartialEq for FullPlaylist